@@ -23,6 +23,19 @@ ERROR_NO_PROFILES_TO_SAVE = (
 ERROR_NO_PROFILES_TO_CLEAR = (
     "There are no profiles to clear."
 )
+ERROR_NO_PROFILES_TO_LIST = (
+    "There are no profiles to list."
+)
 ERROR_NO_PROFILES_TO_DELETE = (
     "There are no profiles to delete."
 )
+ERROR_DJANGO_WITHOUT_SETTINGS = (
+    "Could not find variable 'django_settings_module'.\n"
+    "Run 'iprofile config django [SETTINGS MODULE]' to set it."
+)
+ERROR_DJANGO_INVALID_SETTINGS = (
+    "Could not find settings module '{0}'."
+)
+ERROR_INIT_PATH_EXISTS = (
+    "The folder '{0}' already exists in this project!"
+)
